pub struct DeleteParams {
pub key: String,
pub dry_run: Option<bool>,
}Fields
key: Stringdry_run: Option<bool>Trait Implementations
Sourceimpl Debug for DeleteParams
impl Debug for DeleteParams
Sourceimpl<'de> Deserialize<'de> for DeleteParams
impl<'de> Deserialize<'de> for DeleteParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DeleteParams
impl JsonSchema for DeleteParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeleteParams
impl RefUnwindSafe for DeleteParams
impl Send for DeleteParams
impl Sync for DeleteParams
impl Unpin for DeleteParams
impl UnsafeUnpin for DeleteParams
impl UnwindSafe for DeleteParams