pub struct ExtractParams {
pub key: String,
pub section: Option<String>,
pub block: Option<usize>,
pub list: Option<bool>,
pub dry_run: Option<bool>,
}Fields
key: Stringsection: Option<String>block: Option<usize>list: Option<bool>dry_run: Option<bool>Trait Implementations
Sourceimpl Debug for ExtractParams
impl Debug for ExtractParams
Sourceimpl<'de> Deserialize<'de> for ExtractParams
impl<'de> Deserialize<'de> for ExtractParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractParams
impl JsonSchema for ExtractParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExtractParams
impl RefUnwindSafe for ExtractParams
impl Send for ExtractParams
impl Sync for ExtractParams
impl Unpin for ExtractParams
impl UnsafeUnpin for ExtractParams
impl UnwindSafe for ExtractParams