pub struct RefactorPromptArgs {
pub key: String,
}Fields
key: StringTrait Implementations
Sourceimpl Debug for RefactorPromptArgs
impl Debug for RefactorPromptArgs
Sourceimpl<'de> Deserialize<'de> for RefactorPromptArgs
impl<'de> Deserialize<'de> for RefactorPromptArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefactorPromptArgs
impl JsonSchema for RefactorPromptArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefactorPromptArgs
impl RefUnwindSafe for RefactorPromptArgs
impl Send for RefactorPromptArgs
impl Sync for RefactorPromptArgs
impl Unpin for RefactorPromptArgs
impl UnsafeUnpin for RefactorPromptArgs
impl UnwindSafe for RefactorPromptArgs