pub struct RenameParams {
pub old_key: String,
pub new_key: String,
pub dry_run: Option<bool>,
}Fields
old_key: Stringnew_key: Stringdry_run: Option<bool>Trait Implementations
Sourceimpl Debug for RenameParams
impl Debug for RenameParams
Sourceimpl<'de> Deserialize<'de> for RenameParams
impl<'de> Deserialize<'de> for RenameParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RenameParams
impl JsonSchema for RenameParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RenameParams
impl RefUnwindSafe for RenameParams
impl Send for RenameParams
impl Sync for RenameParams
impl Unpin for RenameParams
impl UnsafeUnpin for RenameParams
impl UnwindSafe for RenameParams