pub struct RetrieveParams {
pub keys: Vec<String>,
pub depth: Option<u8>,
pub context: Option<u8>,
pub links: Option<bool>,
pub backlinks: Option<bool>,
pub exclude: Option<Vec<String>>,
pub no_content: Option<bool>,
pub children: Option<bool>,
pub selector: SelectorParams,
}Fields
keys: Vec<String>depth: Option<u8>context: Option<u8>links: Option<bool>backlinks: Option<bool>exclude: Option<Vec<String>>no_content: Option<bool>children: Option<bool>selector: SelectorParamsTrait Implementations
Sourceimpl Debug for RetrieveParams
impl Debug for RetrieveParams
Sourceimpl<'de> Deserialize<'de> for RetrieveParams
impl<'de> Deserialize<'de> for RetrieveParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<RetrieveParams> for RetrieveOptions
impl From<RetrieveParams> for RetrieveOptions
Sourcefn from(p: RetrieveParams) -> Self
fn from(p: RetrieveParams) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for RetrieveParams
impl JsonSchema for RetrieveParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetrieveParams
impl RefUnwindSafe for RetrieveParams
impl Send for RetrieveParams
impl Sync for RetrieveParams
impl Unpin for RetrieveParams
impl UnsafeUnpin for RetrieveParams
impl UnwindSafe for RetrieveParams