pub struct SquashParams {
pub key: String,
pub depth: Option<u8>,
}Fields
key: Stringdepth: Option<u8>Trait Implementations
Sourceimpl Debug for SquashParams
impl Debug for SquashParams
Sourceimpl<'de> Deserialize<'de> for SquashParams
impl<'de> Deserialize<'de> for SquashParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SquashParams
impl JsonSchema for SquashParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SquashParams
impl RefUnwindSafe for SquashParams
impl Send for SquashParams
impl Sync for SquashParams
impl Unpin for SquashParams
impl UnsafeUnpin for SquashParams
impl UnwindSafe for SquashParams